@@ -772,7 +772,9 @@ class AbstractDataset(tio.data.SubjectsDataset, metaclass=ABCMeta):
         Returns:
             The target spacing for the dataset
         """
-        return self._target_spacing or self.computed_target_spacing
+        if self._target_spacing is None:
+            return self.computed_target_spacing
+        return self._target_spacing
 
     @property
     def num_channels(self) -> int:
@@ -809,7 +811,9 @@ class AbstractDataset(tio.data.SubjectsDataset, metaclass=ABCMeta):
         Returns:
             The target size for the dataset
         """
-        return self._target_size or self.median_size_after_resampling
+        if self._target_size is None:
+            return self.median_size_after_resampling
+        return self._target_size
 
     @property
     def mean_intensity_value(self) -> torch.Tensor:
@@ -938,7 +942,7 @@ class AbstractDiscreteLabelDataset(AbstractDataset):
         """
         return {
             "class_values": torch.tensor(sorted(set(chain.from_iterable(map(itemgetter("class_values"), label_stats))))),
-            "spatial_label_shapes": torch.tensor(tuple(map(attrgetter("spatial_shape"), image_stats)), dtype=torch.long)
+            "spatial_label_shapes": torch.tensor(sorted(set(chain.from_iterable(map(itemgetter("spatial_shape"), label_stats)))), dtype=torch.long)
         }
 
     @property
@@ -946,7 +950,10 @@ class AbstractDiscreteLabelDataset(AbstractDataset):
         if torch.allclose(self.spatial_label_shapes, self.spatial_shapes):
             return self.target_size
         
-        median = spatial_shapes.median(0)
+        if self.spatial_label_shape.numel() == 0:
+            return torch.tensor([1])
+        
+        median = self.spatial_label_shapes.median(0)
         if torch.isnan(median).any():
             return torch.tensor([1])
         return median
